import {
  transformHoistStatic
} from "./chunk-6BNVRGUN.mjs";
import {
  loadSetupComponent,
  transformSetupComponent
} from "./chunk-GYEUIQXF.mjs";
import {
  SETUP_COMPONENT_ID_REGEX
} from "./chunk-AX5V4DNK.mjs";
import {
  transformDefineModel
} from "./chunk-MREMRWUP.mjs";

// src/index.ts
import { createUnplugin } from "unplugin";
import { createFilter } from "@rollup/pluginutils";
import { getPackageInfoSync } from "local-pkg";
import { transform as transformDefineOptions } from "unplugin-vue-define-options";
import {
  finalizeContext,
  getTransformResult,
  initContext
} from "@vue-macros/common";
function resolveOption(options) {
  let version = options.version;
  if (version === void 0) {
    const vuePkg = getPackageInfoSync("vue");
    if (vuePkg) {
      version = +vuePkg.version.slice(0, 1);
    } else {
      version = 3;
    }
  }
  const setupComponent = options.setupComponent === false ? false : [/\.[cm]?[jt]sx?/];
  return {
    include: [/\.vue$/],
    exclude: void 0,
    defineOptions: true,
    defineModel: true,
    hoistStatic: true,
    ...options,
    version,
    setupComponent
  };
}
var name = "unplugin-vue-macros";
function transformVueSFC(code, id, options) {
  const { ctx, getMagicString } = initContext(code, id);
  if (options.hoistStatic)
    transformHoistStatic(ctx);
  if (options.defineOptions)
    transformDefineOptions(ctx);
  if (options.defineModel)
    transformDefineModel(ctx, options.version);
  finalizeContext(ctx);
  return getTransformResult(getMagicString(), id);
}
var src_default = createUnplugin((userOptions = {}) => {
  const options = resolveOption(userOptions);
  const filter = createFilter(options.include, options.exclude);
  const filterGlobalScriptSetup = options.setupComponent ? createFilter(options.setupComponent) : void 0;
  const setupComponentContext = {};
  return {
    name,
    enforce: "pre",
    transformInclude(id) {
      return filter(id) || !!(filterGlobalScriptSetup == null ? void 0 : filterGlobalScriptSetup(id));
    },
    resolveId(id) {
      if (SETUP_COMPONENT_ID_REGEX.test(id))
        return id;
    },
    load(id) {
      if (!SETUP_COMPONENT_ID_REGEX.test(id))
        return;
      return loadSetupComponent(id, setupComponentContext);
    },
    transform(code, id) {
      try {
        if (filter(id)) {
          return transformVueSFC(code, id, options);
        } else if (filterGlobalScriptSetup == null ? void 0 : filterGlobalScriptSetup(id)) {
          return transformSetupComponent(code, id, setupComponentContext);
        }
      } catch (err) {
        this.error(`${name} ${err}`);
      }
    }
  };
});

export {
  src_default
};
